@@ -1,4 +1,4 @@
-from milkyway_sdk.terra_utils import AsyncLCDClient
+from palette_sdk.terra_utils import AsyncLCDClient
 
 DEFAULT_GAS_PRICES = {
     "uluna": "0.15",
